@@ -1,10 +1,10 @@
-# fields, Tools for spatial data
+# LatticeKrig
 # Copyright 2004-2011, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
 
 library(LatticeKrig)
-options( echo=FALSE)
+#options( echo=FALSE)
  test.for.zero.flag<- 1
 
 # small test dataset
@@ -32,7 +32,7 @@ y<- y[1:20]
   test.for.zero( obj1$fitted.values, obj3$fitted.values,
                   tag="comparing predicted values LKrig and Krig")
              
-  test3.se<-predictSE( obj3, x[1:3,])
+  test3.se<-predictSE.Krig( obj3, x[1:3,])
   test2.se<-predictSE.mKrig( obj2, x[1:3,])
   test1.se<- predictSE.LKrig( obj1,  x[1:3,])
   test.for.zero( test1.se, test2.se,
@@ -64,18 +64,16 @@ y<- y[1:20]
 ######## covariates
 ##########################
  set.seed(122)
-Z<- runif(20)
- obj1<- LKrig( x,y,NC=16,nlevel=1, alpha=1,  lambda=lambda, a.wght=5, NtrA=20,iseed=122,
+   nX<- nrow( x)
+   Z<-  matrix(runif(nX*2), ncol=2, nrow=nX)
+   obj1<- LKrig( x,y,NC=16,nlevel=1, alpha=1,  lambda=lambda, a.wght=5, NtrA=20,iseed=122,
                return.cholesky=TRUE, weights=weights, Z=Z)
- obj0<- Krig(  x,y, lambda=lambda, m=2, cov.function="LKrig.cov",
+   obj0<- Krig(  x,y, lambda=lambda, m=2, cov.function="LKrig.cov",
                       cov.args=list( LKinfo=obj1$LKinfo), weights=weights, Z=Z)
   test0<- predictSE( obj0, drop.Z=FALSE, Z=Z)
-  test1<- predictSE( obj1, drop.Z=FALSE, Z=Z)
+  test1<- predictSE( obj1, Z=Z)
   test.for.zero( test0, test1, tag="check on SE values with drop.Z=FALSE")
-#
-  test0<- predictSE( obj0, drop.Z=TRUE)
-  test1<- predictSE( obj1, drop.Z=TRUE)
-  test.for.zero( test0, test1, tag="check on SE values with drop.Z=TRUE")
+
 
 cat("All done with SE tests", fil=TRUE)
 options( echo=TRUE)
